@@ -53,7 +53,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:POINTER,POINTER (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:1) */
+/* VOID:POINTER,POINTER (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:1) */
 extern void _glade_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -72,9 +72,9 @@ _glade_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                       gpointer     arg_1,
                                                       gpointer     arg_2,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -96,10 +96,10 @@ _glade_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:2) */
+/* VOID:POINTER (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:2) */
 #define _glade_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:STRING,ULONG,UINT,STRING (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:3) */
+/* VOID:STRING,ULONG,UINT,STRING (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:3) */
 extern void _glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
@@ -120,9 +120,9 @@ _glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
                                                                guint        arg_3,
                                                                gpointer     arg_4,
                                                                gpointer     data2);
-  register GMarshalFunc_VOID__STRING_ULONG_UINT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_ULONG_UINT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -146,13 +146,13 @@ _glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:4) */
+/* VOID:OBJECT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:4) */
 #define _glade_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:STRING (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:5) */
+/* VOID:STRING (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:5) */
 #define _glade_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:INT,INT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:6) */
+/* VOID:INT,INT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:6) */
 extern void _glade_marshal_VOID__INT_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -171,9 +171,9 @@ _glade_marshal_VOID__INT_INT (GClosure     *closure,
                                               gint         arg_1,
                                               gint         arg_2,
                                               gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -195,7 +195,7 @@ _glade_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:7) */
+/* VOID:OBJECT,OBJECT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:7) */
 extern void _glade_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -214,9 +214,9 @@ _glade_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -238,7 +238,7 @@ _glade_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOOLEAN (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:8) */
+/* VOID:OBJECT,BOOLEAN (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:8) */
 extern void _glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -257,9 +257,9 @@ _glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gboolean     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -281,7 +281,7 @@ _glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:9) */
+/* VOID:STRING,STRING,STRING (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:9) */
 extern void _glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
@@ -301,9 +301,9 @@ _glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                            gpointer     arg_2,
                                                            gpointer     arg_3,
                                                            gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -326,7 +326,7 @@ _glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* OBJECT:POINTER (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:10) */
+/* OBJECT:POINTER (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:10) */
 extern void _glade_marshal_OBJECT__POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -344,9 +344,9 @@ _glade_marshal_OBJECT__POINTER (GClosure     *closure,
   typedef GObject* (*GMarshalFunc_OBJECT__POINTER) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_OBJECT__POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -371,7 +371,7 @@ _glade_marshal_OBJECT__POINTER (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:OBJECT,UINT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:11) */
+/* OBJECT:OBJECT,UINT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:11) */
 extern void _glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -390,9 +390,9 @@ _glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
                                                         gpointer     arg_1,
                                                         guint        arg_2,
                                                         gpointer     data2);
-  register GMarshalFunc_OBJECT__OBJECT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_OBJECT__OBJECT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   GObject* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -418,7 +418,7 @@ _glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* BOOLEAN:STRING (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:12) */
+/* BOOLEAN:STRING (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:12) */
 extern void _glade_marshal_BOOLEAN__STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -436,9 +436,9 @@ _glade_marshal_BOOLEAN__STRING (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__STRING) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -463,7 +463,7 @@ _glade_marshal_BOOLEAN__STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOXED (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:13) */
+/* BOOLEAN:BOXED (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:13) */
 extern void _glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -481,9 +481,9 @@ _glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__BOXED) (gpointer     data1,
                                                    gpointer     arg_1,
                                                    gpointer     data2);
-  register GMarshalFunc_BOOLEAN__BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -508,7 +508,7 @@ _glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:14) */
+/* BOOLEAN:OBJECT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:14) */
 extern void _glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -526,9 +526,9 @@ _glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   typedef gboolean (*GMarshalFunc_BOOLEAN__OBJECT) (gpointer     data1,
                                                     gpointer     arg_1,
                                                     gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -553,7 +553,7 @@ _glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOXED (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:15) */
+/* BOOLEAN:OBJECT,BOXED (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:15) */
 extern void _glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -572,9 +572,9 @@ _glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
                                                           gpointer     arg_1,
                                                           gpointer     arg_2,
                                                           gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -600,7 +600,7 @@ _glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,POINTER (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:16) */
+/* BOOLEAN:OBJECT,POINTER (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:16) */
 extern void _glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -619,9 +619,9 @@ _glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                                             gpointer     arg_1,
                                                             gpointer     arg_2,
                                                             gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -647,7 +647,7 @@ _glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOOLEAN (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:17) */
+/* BOOLEAN:OBJECT,BOOLEAN (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:17) */
 extern void _glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -666,9 +666,9 @@ _glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                                             gpointer     arg_1,
                                                             gboolean     arg_2,
                                                             gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -694,7 +694,7 @@ _glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,UINT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:18) */
+/* BOOLEAN:OBJECT,UINT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:18) */
 extern void _glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -713,9 +713,9 @@ _glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
                                                          gpointer     arg_1,
                                                          guint        arg_2,
                                                          gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -741,7 +741,7 @@ _glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:19) */
+/* BOOLEAN:OBJECT,OBJECT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:19) */
 extern void _glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -760,9 +760,9 @@ _glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                            gpointer     arg_1,
                                                            gpointer     arg_2,
                                                            gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -788,7 +788,7 @@ _glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:20) */
+/* BOOLEAN:OBJECT,STRING (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:20) */
 extern void _glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -807,9 +807,9 @@ _glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                                            gpointer     arg_1,
                                                            gpointer     arg_2,
                                                            gpointer     data2);
-  register GMarshalFunc_BOOLEAN__OBJECT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__OBJECT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -835,7 +835,7 @@ _glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,STRING,STRING,BOXED (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:21) */
+/* BOOLEAN:STRING,STRING,STRING,BOXED (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:21) */
 extern void _glade_marshal_BOOLEAN__STRING_STRING_STRING_BOXED (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -856,9 +856,9 @@ _glade_marshal_BOOLEAN__STRING_STRING_STRING_BOXED (GClosure     *closure,
                                                                         gpointer     arg_3,
                                                                         gpointer     arg_4,
                                                                         gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING_STRING_STRING_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING_STRING_STRING_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -886,7 +886,7 @@ _glade_marshal_BOOLEAN__STRING_STRING_STRING_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,BOXED,OBJECT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:22) */
+/* BOOLEAN:STRING,BOXED,OBJECT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:22) */
 extern void _glade_marshal_BOOLEAN__STRING_BOXED_OBJECT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -906,9 +906,9 @@ _glade_marshal_BOOLEAN__STRING_BOXED_OBJECT (GClosure     *closure,
                                                                  gpointer     arg_2,
                                                                  gpointer     arg_3,
                                                                  gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING_BOXED_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__STRING_BOXED_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -935,7 +935,7 @@ _glade_marshal_BOOLEAN__STRING_BOXED_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* STRING:OBJECT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:23) */
+/* STRING:OBJECT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:23) */
 extern void _glade_marshal_STRING__OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -953,9 +953,9 @@ _glade_marshal_STRING__OBJECT (GClosure     *closure,
   typedef gchar* (*GMarshalFunc_STRING__OBJECT) (gpointer     data1,
                                                  gpointer     arg_1,
                                                  gpointer     data2);
-  register GMarshalFunc_STRING__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_STRING__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gchar* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -980,7 +980,7 @@ _glade_marshal_STRING__OBJECT (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* INT:OBJECT,BOXED (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:24) */
+/* INT:OBJECT,BOXED (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:24) */
 extern void _glade_marshal_INT__OBJECT_BOXED (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -999,9 +999,9 @@ _glade_marshal_INT__OBJECT_BOXED (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   gpointer     arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_INT__OBJECT_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_INT__OBJECT_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gint v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -1027,7 +1027,7 @@ _glade_marshal_INT__OBJECT_BOXED (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* BOXED:OBJECT (/usr/src/ports/glade/glade-3.18.3-1.x86_64/src/glade-3.18.3/gladeui/glade-marshallers.list:25) */
+/* BOXED:OBJECT (/usr/src/ports/glade/glade-3.20.0-1.i686/src/glade-3.20.0/gladeui/glade-marshallers.list:25) */
 extern void _glade_marshal_BOXED__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -1045,9 +1045,9 @@ _glade_marshal_BOXED__OBJECT (GClosure     *closure,
   typedef gpointer (*GMarshalFunc_BOXED__OBJECT) (gpointer     data1,
                                                   gpointer     arg_1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOXED__OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOXED__OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gpointer v_return;
 
   g_return_if_fail (return_value != NULL);
